==> zanata-client-commands-3.1.2-sources.jar: org/zanata/client/commands/stats/GetStatisticsOptions.java <==
/*
 * Copyright 2010, Red Hat, Inc. and individual contributors as indicated by the
 * @author tags. See the copyright.txt file in the distribution for a full
 * listing of individual contributors.
 * 
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA, or see the FSF
 * site: http://www.fsf.org.
 */
package org.zanata.client.commands.stats;

import org.zanata.client.commands.ConfigurableProjectOptions;

/**
 * @author Carlos Munoz <a href="mailto:camunoz@redhat.com">camunoz@redhat.com</a>
 */
public interface GetStatisticsOptions extends ConfigurableProjectOptions
{
   boolean getIncludeDetails();

   void setIncludeDetails(boolean includeDetails);

   boolean getIncludeWordLevelStats();

   void setIncludeWordLevelStats(boolean includeWordLevelStats);

   String getFormat();

   void setFormat( String format );

   String getDocumentId();

   void setDocumentId( String documentId );
}

==> zanata-client-commands-4.1.0-sources.jar: org/zanata/client/commands/stats/GetStatisticsOptions.java <==
/*
 * Copyright 2010, Red Hat, Inc. and individual contributors as indicated by the
 * @author tags. See the copyright.txt file in the distribution for a full
 * listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA, or see the FSF
 * site: http://www.fsf.org.
 */
package org.zanata.client.commands.stats;

import org.zanata.client.commands.ConfigurableProjectOptions;

/**
 * @author Carlos Munoz <a
 *         href="mailto:camunoz@redhat.com">camunoz@redhat.com</a>
 */
public interface GetStatisticsOptions extends ConfigurableProjectOptions {
    boolean getIncludeDetails();

    void setIncludeDetails(boolean includeDetails);

    boolean getIncludeWordLevelStats();

    void setIncludeWordLevelStats(boolean includeWordLevelStats);

    String getFormat();

    void setFormat(String format);

    String getDocumentId();

    void setDocumentId(String documentId);
}
